@@ -9,6 +9,10 @@ def list_batches(las_client: Client, max_results=None, next_token=None):
     return las_client.list_batches(max_results=max_results, next_token=next_token)
 
 
+def delete_batch(las_client: Client, batch_id, delete_documents):
+    return las_client.delete_batch(batch_id, delete_documents=delete_documents)
+
+
 def create_batches_parser(subparsers):
     parser = subparsers.add_parser('batches')
     subparsers = parser.add_subparsers()
@@ -23,4 +27,9 @@ def create_batches_parser(subparsers):
     list_batches_parser.add_argument('--next-token', '-n', default=None)
     list_batches_parser.set_defaults(cmd=list_batches)
 
+    delete_batch_parser = subparsers.add_parser('delete')
+    delete_batch_parser.add_argument('batch_id')
+    delete_batch_parser.add_argument('--delete-documents', action='store_true', default=False)
+    delete_batch_parser.set_defaults(cmd=delete_batch)
+
     return parser
